@@ -4,7 +4,7 @@ use utf8;
 use warnings;
 use strict;
 use Carp;
-use Config::Simple;
+use Config::Simple '-strict';
 use XML::TreeBuilder;
 use I18N::LangTags::List;
 use Term::ANSIColor qw(:constants uncolor);
@@ -15,16 +15,17 @@ use XML::LibXML;
 
 use Publican::Localise;
 
-use vars qw(@ISA $VERSION @EXPORT @EXPORT_OK $SINGLETON $LOCALISE $SPEC_VERSION);
+use vars
+    qw(@ISA $VERSION @EXPORT @EXPORT_OK $SINGLETON $LOCALISE $SPEC_VERSION);
 
-$VERSION = '2.5';
+$VERSION = '2.8';
 @ISA     = qw(Exporter AutoLoader);
 
 @EXPORT
     = qw(dir_list debug_msg get_all_langs logger help_config maketext old2new new_tree);
 
 # Track when the SPEC file generation is incompatible.
-$SPEC_VERSION = '2.5';
+$SPEC_VERSION = '2.6';
 
 my $DEFAULT_CONFIG_FILE = 'publican.cfg';
 my $DEBUG               = undef;
@@ -96,8 +97,7 @@ my %PARAMS = (
 
     },
     bridgehead_in_toc => {
-        descr => maketext(
-            'Display bridge head elements in the TOCs?'),
+        descr   => maketext('Display bridge head elements in the TOCs?'),
         default => 0,
     },
     chunk_first => {
@@ -158,7 +158,7 @@ my %PARAMS = (
     },
     docname => {
         descr => maketext(
-            'Name of this package. Fetched from title tag in xml_lang/TYPE_Info.xml'
+            'Name of this package. Fetched from title tag in xml_lang/TYPE_Info.xml if not set in cfg file.'
         ),
         constraint => '[^0-9a-zA-Z_\-\.\+]',
     },
@@ -176,11 +176,14 @@ my %PARAMS = (
 
     },
     dt_obsoletes => {
-        descr => maketext('Space seperated list of packages the desktop package obsoletes.'),
+        descr => maketext(
+            'Space separated list of packages the desktop package obsoletes.'
+        ),
 
     },
     dt_requires => {
-        descr => maketext('Space seperated list of packages the desktop package requires.'),
+        descr => maketext(
+            'Space separated list of packages the desktop package requires.'),
 
     },
     'ec_id' => {
@@ -220,6 +223,11 @@ my %PARAMS = (
         default => 'GFDL',
 
     },
+    mainfile => {
+        descr => maketext(
+            'The name of the main xml and ent files for this books, sans file extension and language. Fetched from docname if not set.'
+        ),
+    },
     max_image_width => {
         descr => maketext(
             'The maximum pixel width an image can be before it will be scaled.'
@@ -228,12 +236,17 @@ my %PARAMS = (
 
     },
     menu_category => {
-        descr   => maketext('Semi colon seperated list of menu categories for thedesktop package.'),
+        descr => maketext(
+            'Semi colon separated list of menu categories for thedesktop package.'
+        ),
     },
-    os_ver => {
-        descr   => maketext('The OS for which to build packages.'),
-        default => '.el5',
+    no_embedtoc => {
+        descr => maketext(
+            'Brand option to disable embedding the navigational toc in web packages'
+        ),
+        limit_to => 'brand',
     },
+    os_ver  => { descr => maketext('The OS for which to build packages.'), },
     product => {
         descr => maketext(
             'Product this package covers. Fetched from productname tag in xml_lang/TYPE_Info.xml'
@@ -305,15 +318,17 @@ my %PARAMS = (
         descr => maketext(
             'Version of this package. Fetched from productnumber tag in xml_lang/TYPE_Info.xml'
         ),
-        constraint => '[^0-9.]',
+        constraint => '^[^0-9]',
     },
     web_brew_dist => {
         descr   => maketext('The brew dist to use for building the web rpm.'),
         default => 'docs-5E',
     },
     web_formats => {
-        descr   => maketext('A comma seperated loist of the formats to use for the web packages.'),
-        default => 'html,pdf,html-single,epub',
+        descr => maketext(
+            'A comma separated list of the formats to use for the web packages.'
+        ),
+        default => 'html,html-single,pdf,epub',
     },
     web_home => {
         descr => maketext(
@@ -331,16 +346,17 @@ my %PARAMS = (
         descr => maketext(
             'This is a host name for a Publican-generated website, used for searches and the Sitemap. Be sure to include the full path to your document tree. E.g. if your documents are in the docs directory: http://www.example.com/docs'
         ),
-        alert => 'web_host is deprecated and will be removed from Publican in the future. Use "host" in the web site configuration file instead.',
+        alert =>
+            'web_host is deprecated and will be removed from Publican in the future. Use "host" in the web site configuration file instead.',
     },
     web_obsoletes =>
-        { descr => maketext('Packages to obsolete in web RPM.'),
-    },
+        { descr => maketext('Packages to obsolete in web RPM.'), },
     web_search => {
         descr => maketext(
             'Override the default search form for a Publican website. By default this will use Google search and do a site search if web_host is set.'
         ),
-        alert => 'web_search is deprecated and will be removed from Publican in the future. Use "search" in the web site configuration file instead.',
+        alert =>
+            'web_search is deprecated and will be removed from Publican in the future. Use "search" in the web site configuration file instead.',
     },
     web_name_label => {
         descr => maketext(
@@ -444,11 +460,12 @@ sub _load_config {
             $config->param( $def, $PARAMS{$def}->{default} );
         }
 
-       # Output alerts about a parameter
-       if( defined $PARAMS{$def}->{alert}
-            and defined( $config->param($def) )) {
-           _alert($PARAMS{$def}->{alert} . "\n");
-       }
+        # Output alerts about a parameter
+        if (    defined $PARAMS{$def}->{alert}
+            and defined( $config->param($def) ) )
+        {
+            _alert( $PARAMS{$def}->{alert} . "\n" );
+        }
     }
 
     $config->param( 'common_config',  $common_config )  if $common_config;
@@ -510,6 +527,10 @@ sub _load_config {
             croak maketext("pubsnumber not found in Info file");
         }
 
+        if ( not defined( $self->{config}->param('mainfile') ) ) {
+            $self->{config}->param( 'mainfile', $docname );
+        }
+
         $self->{config}->param( 'docname', $docname );
         $self->{config}->param( 'product', $product );
         $self->{config}->param( 'version', $version );
@@ -797,7 +818,7 @@ sub dir_list {
     croak( maketext("dir is a required argument") ) unless ($dir);
 
     unless ( -d $dir ) {
-        logger( maketext( "skiping non existant directory: [_1]", $dir ) );
+        logger( maketext( "skipping non existent directory: [_1]", $dir ) );
         return;
     }
 
@@ -846,7 +867,7 @@ sub get_all_langs {
 
 =head2 logger
 
-Log something, currently emits to STDERR
+Log something, currently emits to STDOUT
 
 TODO: consider using Log::Dispatch or similar
 
@@ -858,10 +879,10 @@ sub logger {
     return if ($QUIET);
 
     if ( $colour && !$NOCOLOURS ) {
-        print( STDERR $colour, $msg, RESET );
+        print( STDOUT $colour, $msg, RESET );
     }
     else {
-        print( STDERR $msg );
+        print( STDOUT $msg );
     }
 
     return;
@@ -914,7 +935,7 @@ sub old2new {
 
     # get all the variable names defined in the Makefile:
     my @vars = $parser->vars();
-    print( STDERR "found: " . join( ' ', sort @vars ) . "\n" );
+    print( STDOUT "found: " . join( ' ', sort @vars ) . "\n" );
 
     my $config = new Config::Simple();
     $config->syntax('http');
@@ -948,7 +969,8 @@ Return the abstract for the supplied langauge with all white space truncted.
 sub get_abstract {
     my ( $self, $args ) = @_;
 
-    my $lang = delete( $args->{lang} )|| croak( maketext("lang is a mandatory argument") );
+    my $lang = delete( $args->{lang} )
+        || croak( maketext("lang is a mandatory argument") );
 
     if ( %{$args} ) {
         croak(
@@ -958,14 +980,17 @@ sub get_abstract {
         );
     }
 
-    my $tmp_dir    = $self->param('tmp_dir');
-    my $info_file = "$tmp_dir/$lang/xml/" . $self->param('type') . '_Info.xml';
+    my $tmp_dir = $self->param('tmp_dir');
+    my $info_file
+        = "$tmp_dir/$lang/xml/" . $self->param('type') . '_Info.xml';
 
-    croak(maketext("abstract can not be calculated before building.")) unless (-f $info_file);
+    croak( maketext("abstract can not be calculated before building.") )
+        unless ( -f $info_file );
 
     my $xsl_file = $self->param('common_config') . "/xsl/abstract.xsl";
 
-    my $abstract = $self->run_xslt({xml_file => $info_file, xsl_file => $xsl_file});
+    my $abstract = $self->run_xslt(
+        { xml_file => $info_file, xsl_file => $xsl_file } );
 
     # tidy up white space
     $abstract =~ s/^[ \t]*//gm;
@@ -974,9 +999,11 @@ sub get_abstract {
     $abstract =~ s/\n\n\n/\n\n/g;
     $abstract =~ s/[ \t][ \t]+/ /gm;
 
-    return($abstract);
-}
+    # RPM doesn't like non-breaking-space
+    $abstract =~ s/\x{A0}/ /gm;
 
+    return ($abstract);
+}
 
 =head2 get_subtitle
 
@@ -987,7 +1014,8 @@ Return the subtitle for the supplied langauge with white space truncted.
 sub get_subtitle {
     my ( $self, $args ) = @_;
 
-    my $lang = delete( $args->{lang} )|| croak( maketext("lang is a mandatory argument") );
+    my $lang = delete( $args->{lang} )
+        || croak( maketext("lang is a mandatory argument") );
 
     if ( %{$args} ) {
         croak(
@@ -997,20 +1025,26 @@ sub get_subtitle {
         );
     }
 
-    my $tmp_dir    = $self->param('tmp_dir');
-    my $info_file = "$tmp_dir/$lang/xml/" . $self->param('type') . '_Info.xml';
+    my $tmp_dir = $self->param('tmp_dir');
+    my $info_file
+        = "$tmp_dir/$lang/xml/" . $self->param('type') . '_Info.xml';
 
-    croak(maketext("subtitle can not be calculated before building.")) unless (-f $info_file);
+    croak( maketext("subtitle can not be calculated before building.") )
+        unless ( -f $info_file );
 
     my $xsl_file = $self->param('common_config') . "/xsl/subtitle.xsl";
 
-    my $subtitle = $self->run_xslt({xml_file => $info_file, xsl_file => $xsl_file});
+    my $subtitle = $self->run_xslt(
+        { xml_file => $info_file, xsl_file => $xsl_file } );
 
     # tidy up white space
     $subtitle =~ s/^\s*//gm;
+
+    # RPM doesn't like non-breaking-space
+    $subtitle =~ s/\x{A0}/ /gm;
     $subtitle =~ s/\s+/ /;
 
-    return($subtitle);
+    return ($subtitle);
 }
 
 =head2 run_xslt
@@ -1021,9 +1055,9 @@ Apply the supplied xslt file to teh supplied XML and return a string of the outp
 
 sub run_xslt {
     my ( $self, $args ) = @_;
-    my $xml_file =  delete( $args->{xml_file} )
+    my $xml_file = delete( $args->{xml_file} )
         || croak( maketext("xml_file is a mandatory argument") );
-    my $xsl_file =  delete( $args->{xsl_file} )
+    my $xsl_file = delete( $args->{xsl_file} )
         || croak( maketext("xsl_file is a mandatory argument") );
 
     if ( %{$args} ) {
@@ -1092,11 +1126,11 @@ sub run_xslt {
     }
 
     my $stylesheet = $xslt->parse_stylesheet($style_doc);
-    my $results = $stylesheet->transform( $source );
+    my $results    = $stylesheet->transform($source);
     my $value;
     eval { $value = $stylesheet->output_string($results) };
 
-    return($value);
+    return ($value);
 }
 
 =head2 new_tree
@@ -1217,7 +1251,7 @@ No bugs have been reported.
 
 Please report any bugs or feature requests to
 C<publican-list@redhat.com>, or through the web interface at
-L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Fedora&amp;version=rawhide&amp;component=publican>.
+L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Publican&amp;component=publican>.
 
 =head1 AUTHOR
 
