@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use 5.008;
 use Carp;
-use Config::Simple;
+use Config::Simple '-strict';
 use Publican;
 use Publican::XmlClean;
 use Publican::Translate;
@@ -29,6 +29,7 @@ use Locale::Language;
 use List::Util qw(max);
 use Text::Wrap qw(fill $columns);
 use IO::String;
+use File::Which;
 
 use vars qw(@ISA $VERSION @EXPORT @EXPORT_OK);
 
@@ -128,7 +129,8 @@ sub build {
     my $type    = $self->{publican}->param('type');
     my $brand   = $self->{publican}->param('brand');
 
-    if ( $type eq 'Set' && $self->{publican}->{config}->param('scm') ) {
+    if ( ( $type eq 'Set' ) && ( $self->{publican}->{config}->param('scm') ) )
+    {
         $self->get_books();
         $self->build_set_books( { langs => $langs } );
     }
@@ -414,12 +416,12 @@ sub setup_xml {
                 ) if ( $lang ne $brand_lang );
             }
 
-            my $ent_file
-                = "$xml_lang/" . $self->{publican}->param('docname') . ".ent";
+            my $main_file = $self->{publican}->param('mainfile');
+
+            my $ent_file = "$xml_lang/$main_file.ent";
             rcopy( $ent_file, "$tmp_dir/$lang/xml/." ) if ( -e $ent_file );
 
-            $ent_file
-                = $lang . "/" . $self->{publican}->param('docname') . ".ent";
+            $ent_file = "$lang/$main_file.ent";
             rcopy( $ent_file, "$tmp_dir/$lang/xml/." ) if ( -e $ent_file );
 
             dircopy( "$xml_lang/extras", "$tmp_dir/$lang/xml/extras" )
@@ -542,8 +544,9 @@ sub validate_xml {
         );
     }
 
-    my $docname = $self->{publican}->param('docname');
-    my $dtdver  = $self->{publican}->param('dtdver');
+    my $docname   = $self->{publican}->param('docname');
+    my $dtdver    = $self->{publican}->param('dtdver');
+    my $main_file = $self->{publican}->param('mainfile');
 
     if (   ( $self->{publican}->param('ignored_translations') )
         && ( $self->{publican}->param('ignored_translations') =~ m/$lang/ ) )
@@ -575,11 +578,12 @@ sub validate_xml {
         $parser->expand_xinclude(1);
     }
 
-    croak( maketext( "Cannot locate main XML file: '[_1]'", "$docname.xml" ) )
-        unless ( -f "$docname.xml" );
+    croak(
+        maketext( "Cannot locate main XML file: '[_1]'", "$main_file.xml" ) )
+        unless ( -f "$main_file.xml" );
 
     my $source;
-    eval { $source = $parser->parse_file("$docname.xml"); };
+    eval { $source = $parser->parse_file("$main_file.xml"); };
 
     if ($@) {
         if ( ref($@) ) {
@@ -675,6 +679,10 @@ sub transform {
 
     my $dir;
 
+## BUGBUG test an alternative to fop!
+    my $wkhtmltopdf_cmd = which('wkhtmltopdf');
+    my $diefopdie = ( $wkhtmltopdf_cmd && $wkhtmltopdf_cmd ne '' );
+
     my $tmp_dir           = $self->{publican}->param('tmp_dir');
     my $docname           = $self->{publican}->param('docname');
     my $common_config     = $self->{publican}->param('common_config');
@@ -698,6 +706,7 @@ sub transform {
     my $ec_provider         = $self->{publican}->param('ec_provider');
     my $product             = $self->{publican}->param('product');
     my $bridgehead_in_toc   = $self->{publican}->param('bridgehead_in_toc');
+    my $main_file           = $self->{publican}->param('mainfile');
 
     my $TAR_NAME
         = $self->{publican}->param('product') . '-'
@@ -707,6 +716,12 @@ sub transform {
 
     my $RPM_RELEASE = $self->{publican}->param('release');
 
+    my $pdf_name
+        = $self->{publican}->param('product') . '-'
+        . $self->{publican}->param('version') . '-'
+        . $self->{publican}->param('docname') . '-'
+        . "$lang.pdf";
+
     if ( $format eq 'txt' ) {
         if ( !-e "$tmp_dir/$lang/html-single" ) {
             $self->transform( { lang => $lang, format => 'html-single' } );
@@ -715,10 +730,12 @@ sub transform {
         $dir = pushd("$tmp_dir/$lang");
         mkdir 'txt';
         my $TXT_FILE;
-        open( $TXT_FILE, ">", "txt/$docname.txt" )
+        open( $TXT_FILE, ">:encoding(UTF-8)", "txt/$docname.txt" )
             || croak( maketext("Can't open file for text output!") );
-        my $tree
-            = HTML::TreeBuilder->new->parse_file("html-single/index.html");
+        my $tree = HTML::TreeBuilder->new();
+        my $fh;
+        open( $fh, "<:encoding(UTF-8)", "html-single/index.html" );
+        $tree->parse_file($fh);
         my $formatter
             = HTML::FormatText->new( leftmargin => 0, rightmargin => 72 );
         print( $TXT_FILE $formatter->format($tree) );
@@ -727,6 +744,41 @@ sub transform {
         return;
     }
 
+    if ( $format eq 'pdf' && $diefopdie ) {
+        if ( !-e "$tmp_dir/$lang/html-single" ) {
+            $self->transform( { lang => $lang, format => 'html-single' } );
+        }
+
+        mkdir "$tmp_dir/$lang/pdf";
+#        $dir = pushd("$tmp_dir/$lang/html-single");
+
+        my($web_product_label, $web_version_label, $web_name_label) = $self->web_labels({lang => $lang, xml_lang => $xml_lang});
+
+        my $title = (   $web_product_label || $self->{publican}->param('product') ) . ' ' .
+                ( $web_version_label || $self->{publican}->param('version') ) . ' ' .
+                ($web_name_label    || $self->{publican}->param('docname') );
+
+utf8::encode($title);
+logger("title: $title\n");
+
+        $title =~ s/_/ /g;
+
+        # BUGBUG how to find out where footer.html is on all OS's?
+        my @wkhtmltopdf_args = (
+            $wkhtmltopdf_cmd,                  '--header-spacing',
+            5,                                 '--margin-top',
+            20,                                '--header-html',
+            '/usr/share/publican/header.html', '--title',
+            $title,                            "$tmp_dir/$lang/html-single/index.html",
+            "$tmp_dir/$lang/pdf/$pdf_name"
+        );
+        my $result = system(@wkhtmltopdf_args);
+        if ($result) {
+## BUGBUG what to do if it dies?
+        }
+        return;
+    }
+
     my $xsl_file = $common_config . "/xsl/$format.xsl";
     $xsl_file = $common_content . "/$brand/xsl/$format.xsl"
         if ( -f $common_content . "/$brand/xsl/$format.xsl" );
@@ -858,9 +910,9 @@ sub transform {
 
     $parser->expand_xinclude(1);
     $parser->expand_entities(1);
-##    my $source = $parser->parse_file("../xml/$docname.xml");
+
     my $source;
-    eval { $source = $parser->parse_file("../xml/$docname.xml"); };
+    eval { $source = $parser->parse_file("../xml/$main_file.xml"); };
 
     if ($@) {
         if ( ref($@) ) {
@@ -929,12 +981,6 @@ sub transform {
     croak( maketext( "Transformation error '[_1]' : [_2]", $!, $@ ) ) if $@;
 
     if ( $format =~ /^pdf/ ) {
-        my $pdf_name
-            = $self->{publican}->param('product') . '-'
-            . $self->{publican}->param('version') . '-'
-            . $self->{publican}->param('docname') . '-'
-            . "$lang.pdf";
-
         my $fop_command
             = qq|CLASSPATH="$classpath" fop -q -c $common_config/fop/fop.xconf -fo $docname.fo -pdf ../pdf/$pdf_name|;
 
@@ -944,7 +990,15 @@ sub transform {
                 = qq|fop -q -c $common_config/fop/fop.xconf -fo $docname.fo -pdf ../pdf/$pdf_name|;
         }
 
-        system($fop_command);
+        if ( system($fop_command) != 0 ) {
+            croak(
+                "\n",
+                maketext(
+                    "FOP error, PDF generation failed. Check log for details."
+                ),
+                "\n"
+            );
+        }
 
         $dir = undef;
     }
@@ -1490,6 +1544,7 @@ Returns: Modified input tree, which is DocBook XML.
 =cut
 
 sub numberLines {
+    my $count   = shift()->string_value();
     my $content = shift();
 
     my $parser = XML::LibXML->new();
@@ -1500,19 +1555,23 @@ sub numberLines {
     my $format    = '%' . length("$num_lines") . 's:' . chr(160);
 
     my $out_string = $text;
-    my $count      = 0;
     $out_string =~ s/^/sprintf("$format",$count++)/egm;
 
     # this gives an XML::LibXML::DocumentFragment
-    my $list = $parser->parse_balanced_chunk($out_string);
+    # BUGBUG testing BZ #653432
+    # my $list = $parser->parse_balanced_chunk($out_string);
+    my $list = XML::LibXML::Text->new($out_string);
 
     # remove the input node
     $content->shift;
 
+    # BUGBUG testing BZ #653432
+    $content->push($list);
+
     # append the marked-up nodes
-    foreach my $node ( $list->childNodes() ) {
-        $content->push($node);
-    }
+    #    foreach my $node ( $list->childNodes() ) {
+    #        $content->push($node);
+    #    }
 
     return ($content);
 }
@@ -1539,7 +1598,6 @@ sub package_brand {
     my $name    = lc( $self->{publican}->param('brand') );
     my $version = $self->{publican}->param('version');
     my $release = $self->{publican}->param('release');
-    my $os_ver  = $self->{publican}->param('os_ver');
 
     my $tardir = "publican-$name-$version";
     mkpath("$tmp_dir/tar/$tardir");
@@ -1635,12 +1693,14 @@ sub package_home {
     my $xsl_file      = $common_config . "/xsl/web-home-spec.xsl";
     $xsl_file =~ s/"//g;    # windows
 
-    my $license = $self->{publican}->param('license');
-    my $brand   = 'publican-' . lc( $self->{publican}->param('brand') );
-    my $doc_url = $self->{publican}->param('doc_url');
-    my $src_url = $self->{publican}->param('src_url');
-    my $os_ver  = $self->{publican}->param('os_ver');
-    my $log     = $self->change_log();
+    my $license  = $self->{publican}->param('license');
+    my $brand    = 'publican-' . lc( $self->{publican}->param('brand') );
+    my $doc_url  = $self->{publican}->param('doc_url');
+    my $src_url  = $self->{publican}->param('src_url');
+    my $log      = $self->change_log();
+    my $embedtoc = '--embedtoc';
+
+    $embedtoc = "" if ( $self->{publican}->param('no_embedtoc') );
 
     my %xslt_opts = (
         'book-title' => $name_start,
@@ -1657,6 +1717,7 @@ sub package_home {
         tmpdir       => $tmp_dir,
         web_type     => $web_type,
         spec_version => $Publican::SPEC_VERSION,
+        embedtoc     => $embedtoc,
     );
 
     logger(
@@ -1675,7 +1736,7 @@ sub package_home {
     my $outfile;
     my $spec_name = "$tmp_dir/rpm/$name_start-web-$web_type.spec";
 
-    open( $outfile, ">:utf8", "$spec_name" )
+    open( $outfile, ">:encoding(UTF-8)", "$spec_name" )
         || croak( maketext( "Can't open spec file: [_1]", $@ ) );
     print( $outfile $stylesheet->output_string($results) );
     close($outfile);
@@ -1731,16 +1792,26 @@ sub build_rpm {
             . "\n"
     );
 
-    if (system( $rpmbuild, "--define",
-            "_sourcedir $dir", "--define",
-            "_builddir $dir",  "--define",
-            "_srcrpmdir $dir", "--define",
-            "_rpmdir $dir", ( $binary ? "-ba" : ( "-bs", "--nodeps" ) ),
-            "--define", "dist $os_ver",
-            $spec
-        ) != 0
-        )
-    {
+    my @rpm_args = (
+        "--define", "_sourcedir $dir", "--define", "_builddir $dir",
+        "--define", "_srcrpmdir $dir", "--define", "_rpmdir $dir"
+    );
+
+    if ($binary) {
+        push( @rpm_args, "-ba" );
+    }
+    else {
+        push( @rpm_args, "-bs", "--nodeps" );
+    }
+
+    if ($os_ver) {
+        $os_ver = ".$os_ver" unless ( $os_ver =~ m/^\./ );
+        push( @rpm_args, "--define", "dist $os_ver" );
+    }
+
+    push( @rpm_args, $spec );
+
+    if ( system( $rpmbuild, @rpm_args ) != 0 ) {
         if ( $? == -1 ) {
             croak maketext( "Failed to execute [_1], error number: [_2]",
                 $rpmbuild, $! )
@@ -1805,6 +1876,9 @@ sub package {
     my $type              = $self->{publican}->param('type');
     my $web_formats_comma = $self->{publican}->param('web_formats');
     my $web_formats       = $web_formats_comma;
+    my $embedtoc          = '--embedtoc';
+
+    $embedtoc = "" if ( $self->{publican}->param('no_embedtoc') );
 
     $web_formats =~ s/,/ /g;
 
@@ -1824,7 +1898,7 @@ sub package {
         if ( -f $po_file ) {
             my $PO;
             my $real_value;
-            open( $PO, "<:utf8", $po_file )
+            open( $PO, "<:encoding(UTF-8)", $po_file )
                 || croak( maketext( "Can't open PO file: [_1]", $po_file ) );
             foreach my $line (<$PO>) {
                 if ( $line =~ /^"Project-Id-Version:/ ) {
@@ -1864,7 +1938,8 @@ sub package {
     $tardir = "$name_start-$lang-$edition" if ($short_sighted);
 
     # distributed sets need to be collected before packaging
-    if ( $type eq 'Set' ) {
+    if ( ( $type eq 'Set' ) && ( $self->{publican}->{config}->param('scm') ) )
+    {
         $self->get_books();
         $self->build_set_books( { langs => $lang } );
     }
@@ -1876,12 +1951,12 @@ sub package {
     rmtree("$tmp_dir/tar/$tardir/$lang/Common_Content");
     mkpath("$tmp_dir/rpm");
 
-    dircopy( "$xml_lang/icons", "$tmp_dir/tar/$tardir/icons" )
+    dircopy( "$xml_lang/icons", "$tmp_dir/tar/$tardir/$lang/icons" )
         if ( -e "$xml_lang/icons" );
-    dircopy( "$lang/icons", "$tmp_dir/tar/$tardir/icons" )
+    dircopy( "$lang/icons", "$tmp_dir/tar/$tardir/$lang/icons" )
         if ( -e "$lang/icons" );
-    finddepth( \&del_unwanted_dirs, "$tmp_dir/tar/$tardir/icons" )
-        if ( -e "$tmp_dir/tar/$tardir/icons" );
+    finddepth( \&del_unwanted_dirs, "$tmp_dir/tar/$tardir/$lang/icons" )
+        if ( -e "$tmp_dir/tar/$tardir/$lang/icons" );
 
     dircopy( "$xml_lang/files", "$tmp_dir/tar/$tardir/$lang/files" )
         if ( -e "$xml_lang/files" );
@@ -1900,19 +1975,6 @@ sub package {
         $self->{publican}->{config}->delete('scm');
     }
 
-    $self->{publican}->{config}->param( 'release', $release );
-
-    $self->{publican}->{config}->write("$tmp_dir/tar/$tardir/publican.cfg");
-    $self->{publican}->{config}->delete('release');
-    $self->{publican}->{config}->param( 'xml_lang', $xml_lang );
-    $self->{publican}->{config}->param( 'scm', $tmp_scm ) if ($tmp_scm);
-
-    my $dir = pushd("$tmp_dir/tar");
-    my @files = dir_list( $tardir, '*' );
-    Archive::Tar->create_archive( "../rpm/$tardir-$release.tgz", 9, @files );
-
-    $dir = undef;
-
     my $common_config = $self->{publican}->param('common_config');
     my $xsl_file      = $common_config . "/xsl/web-spec.xsl";
     $xsl_file = $common_config . "/xsl/dt_htmlsingle_spec.xsl" if ($desktop);
@@ -1924,57 +1986,48 @@ sub package {
     my $dt_obsoletes      = $self->{publican}->param('dt_obsoletes') || "";
     my $dt_requires       = $self->{publican}->param('dt_requires') || "";
     my $web_obsoletes     = $self->{publican}->param('web_obsoletes') || "";
-    my $os_ver            = $self->{publican}->param('os_ver');
     my $translation       = ( $lang ne $xml_lang );
     my $language          = code2language( substr( $lang, 0, 2 ) );
-    my $web_product_label = $self->{publican}->param('web_product_label')
-        || "";
-    my $web_version_label = $self->{publican}->param('web_version_label')
-        || "";
-    my $web_name_label = $self->{publican}->param('web_name_label') || "";
+
+
+    my($web_product_label, $web_version_label, $web_name_label) = $self->web_labels({lang => $lang, xml_lang => $xml_lang});
 
     my $menu_category = $self->{publican}->param('menu_category')
         || "X-Red-Hat-Base;";
     $menu_category .= ';' if ( $menu_category !~ /;\s*$/ );
 
-    if ( $lang ne $xml_lang ) {
-        my $xml_file = "$tmp_dir/$lang/xml/$type" . '_Info.xml';
-        croak( maketext( "Can't locate required file: [_1]", $xml_file ) )
-            if ( !-f $xml_file );
+    # store lables for rebuilding translated content
+    $self->{publican}->{config}->param( 'web_product_label', $web_product_label );
+    $self->{publican}->{config}->param( 'web_version_label', $web_version_label );
+    $self->{publican}->{config}->param( 'web_name_label', $web_name_label );
 
-        my $xml_doc = XML::TreeBuilder->new();
-        $xml_doc->parse_file($xml_file);
+    $self->{publican}->{config}->param( 'release', $release );
 
-        # BUGBUG can't translate overridden labels :(
-        unless ($web_product_label) {
-            $web_product_label = eval {
-                $xml_doc->root()->look_down( "_tag", "productname" )
-                    ->as_text();
-            };
-            if ($@) {
-                croak maketext("productname not found in Info file");
-            }
-            $web_product_label =~ s/\s/_/g;
-        }
+    # don't override these
+    $self->{publican}->{config}->delete('common_config');
+    my $common_content = $self->{publican}->param('common_content');
+    $self->{publican}->{config}->delete('common_content');
+    $self->{publican}->{config}->delete('strict');
 
-        unless ($web_name_label) {
-            $web_name_label = eval {
-                $xml_doc->root()->look_down( "_tag", "title" )->as_text();
-            };
-            if ($@) {
-                croak maketext("title not found in Info file");
-            }
-            $web_name_label =~ s/\s/_/g;
-        }
-    }
+    $self->{publican}->{config}->write("$tmp_dir/tar/$tardir/publican.cfg");
 
-    $web_product_label =~ s/'/\\'/g;
-    $web_name_label    =~ s/'/\\'/g;
-    $web_version_label =~ s/'/\\'/g;
+    $self->{publican}->{config}->param( 'common_config',  $common_config );
+    $self->{publican}->{config}->param( 'common_content', $common_content );
+
+    $self->{publican}->{config}->delete('release');
+    $self->{publican}->{config}->param( 'xml_lang', $xml_lang );
+    $self->{publican}->{config}->param( 'scm', $tmp_scm ) if ($tmp_scm);
+
+    my $dir = pushd("$tmp_dir/tar");
+    my @files = dir_list( $tardir, '*' );
+    Archive::Tar->create_archive( "../rpm/$tardir-$release.tgz", 9, @files );
+
+    $dir = undef;
 
     my $log = $self->change_log();
 
     my $full_abstract = $self->{publican}->get_abstract( { lang => $lang } );
+    $full_abstract =~ s/\p{Z}+/ /g;
 
     # Wrap description for RPM style requirements
     $columns = 68;
@@ -1982,10 +2035,11 @@ sub package {
     $columns = $DEFAULT_WRAP;
 
     # Escape single quotes to prevent bash breaking
-    $full_abstract =~ s/'/\\'/g;
+    $full_abstract =~ s/"/\\"/g;
 
     my $full_subtitle = $self->{publican}->get_subtitle( { lang => $lang } );
-    $full_subtitle =~ s/'/\\'/g;
+    $full_subtitle =~ s/"/\\"/g;
+    $full_subtitle =~ s/\p{Z}+/ /g;
     chomp($full_subtitle);
 
     my %xslt_opts = (
@@ -2018,8 +2072,30 @@ sub package {
         web_formats_comma => $web_formats_comma,
         menu_category     => $menu_category,
         spec_version      => $Publican::SPEC_VERSION,
+        embedtoc          => $embedtoc,
     );
 
+    # \p{Z} is unicode white space, which is a super set of ascii white space.
+    if ( $full_abstract !~ /[^\p{Z}]/ ) {
+        logger(
+            maketext(
+                "WARNING: You can not create RPM packages with a blank abstract. Skipping RPM creation.\n"
+            ),
+            RED
+        );
+        return;
+    }
+
+    if ( $full_subtitle !~ /[^\p{Z}]/ ) {
+        logger(
+            maketext(
+                "WARNING: You can not create RPM packages with a blank subtitle. Skipping RPM creation.\n"
+            ),
+            RED
+        );
+        return;
+    }
+
     logger(
         "\t" . maketext( "Using XML::LibXSLT on [_1]", $xsl_file ) . "\n" );
 
@@ -2039,7 +2115,7 @@ sub package {
     $spec_name = "$tmp_dir/rpm/$name_start-$lang.spec"
         if ( $desktop or $short_sighted );
 
-    open( $outfile, ">:utf8", "$spec_name" )
+    open( $outfile, ">:encoding(UTF-8)", "$spec_name" )
         || croak( maketext( "Can't open spec file: [_1]", $@ ) );
     print( $outfile $stylesheet->output_string($results) );
     close($outfile);
@@ -2049,6 +2125,90 @@ sub package {
     return;
 }
 
+=head2 web_labels
+
+Determine if the labels use in the web navigation are different from the names used for packaging.
+
+=cut
+
+sub web_labels {
+    my ( $self, $args ) = @_;
+
+    my $lang = delete( $args->{lang} )
+        || croak( maketext("lang is a mandatory argument") );
+    my $xml_lang = delete( $args->{xml_lang} )
+        || croak( maketext("xml_lang is a mandatory argument") );
+
+    if ( %{$args} ) {
+        croak(
+            maketext(
+                "unknown arguments: [_1]", join( ", ", keys %{$args} )
+            )
+        );
+    }
+
+    my $tmp_dir           = $self->{publican}->param('tmp_dir');
+    my $type              = $self->{publican}->param('type');
+    my $docname           = $self->{publican}->param('docname');
+    my $product           = $self->{publican}->param('product');
+    my $version           = $self->{publican}->param('version');
+
+    my $web_product_label = $self->{publican}->param('web_product_label') || undef;
+    my $web_version_label = $self->{publican}->param('web_version_label') || undef;
+    my $web_name_label = $self->{publican}->param('web_name_label') || undef;
+
+
+    if ( $lang ne $xml_lang ) {
+        my $xml_file = "$tmp_dir/$lang/xml/$type" . '_Info.xml';
+        croak( maketext( "Can't locate required file: [_1]", $xml_file ) )
+            if ( !-f $xml_file );
+
+        my $xml_doc = XML::TreeBuilder->new();
+        $xml_doc->parse_file($xml_file);
+
+        # BUGBUG can't translate overridden labels :(
+        unless ($web_product_label) {
+            $web_product_label = eval {
+                $xml_doc->root()->look_down( "_tag", "productname" )
+                    ->as_text();
+            };
+            if ($@) {
+                croak maketext("productname not found in Info file");
+            }
+            $web_product_label =~ s/\s/_/g;
+        }
+
+        unless ($web_name_label) {
+            $web_name_label = eval {
+                $xml_doc->root()->look_down( "_tag", "title" )->as_text();
+            };
+            if ($@) {
+                croak maketext("title not found in Info file");
+            }
+            $web_name_label =~ s/\s/_/g;
+        }
+    }
+
+    $web_product_label =~ s/"/\\"/g if($web_product_label);
+    $web_name_label    =~ s/"/\\"/g if($web_name_label);
+    $web_version_label =~ s/"/\\"/g if($web_version_label);
+
+    if ( $web_name_label && $web_name_label eq $docname ) {
+        $web_name_label = undef;
+    }
+    
+    if ( $web_version_label && $web_version_label eq $version ) {
+        $web_version_label = undef;
+    }
+
+    if ( $web_product_label && $web_product_label eq $product ) {
+        $web_product_label = undef;
+    }
+
+    return($web_product_label, $web_version_label, $web_name_label);
+}
+
+
 =head2 change_log
 
 Generate an RPM style change log from $xml_lang/Revision_History.xml
@@ -2123,15 +2283,14 @@ sub change_log {
 
         my $revnumber = $node->as_trimmed_text();
 
-        unless ( $revnumber =~ m/-\d/ ) {
-            logger(
+        unless ( $revnumber =~ m/\d[0-9.]*-\d[0-9.]*/ ) {
+            croak(
                 maketext(
-                    "WARNING: revnumber '[_1]' does not match required format '(\\d.)*-(\\d.)*'. e.g. '[_1]-0'.\nWARNING: Appending '-0' to revnumber for change log use to avoid creating invalid change log entries.\nWARNING: This automated handling is deprecated and will be removed from Publican in a future version, you should correct your revnumber's before this or your future builds will fail.\n\n",
-                    $revnumber
-                ),
-                RED
+                    "ERROR: revnumber '[_1]' does not match required format [_2]. e.g. '1-1'.\n",
+                    $revnumber,
+                    q|\d[0-9.]*-\d[0-9.]*|
+                )
             );
-            $revnumber .= '-0';
         }
 
         $log .= sprintf( "* %s %s %s <%s> - %s\n",
@@ -2474,7 +2633,7 @@ No bugs have been reported.
 
 Please report any bugs or feature requests to
 C<publican-list@redhat.com>, or through the web interface at
-L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Fedora&amp;version=rawhide&amp;component=publican>.
+L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Publican&amp;component=publican>.
 
 
 =head1 AUTHOR
