@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008;
 use Carp;
-use Config::Simple;
+use Config::Simple '-strict';
 use XML::TreeBuilder;
 use File::Path;
 use DateTime;
@@ -222,12 +222,7 @@ sub create {
                     [   'remark',
                         '<xi:include href="My_Other_Book/My_Other_Book.xml" xmlns:xi="http://www.w3.org/2001/XInclude">'
                     ],
-                    [   'xi:include',
-                        {   href       => 'Revision_History.xml',
-                            'xmlns:xi' => 'http://www.w3.org/2001/XInclude'
-                        }
-                    ],
-                    ['index'],
+                    ['setindex'],
                 ],
             ),
         },
@@ -372,7 +367,7 @@ sub create {
             $out_file = "$name/$lang/$name" . ".xml";
         }
         my $OUTDOC;
-        open( $OUTDOC, ">:utf8", $out_file )
+        open( $OUTDOC, ">:encoding(UTF-8)", $out_file )
             || croak(
             maketext( "Could not open [_1] for output!", $out_file, $@ ) );
 
@@ -399,7 +394,7 @@ sub create {
     my $year = DateTime->today()->year();
 
     my $OUTDOC;
-    open( $OUTDOC, ">:utf8", "$name/$lang/$name" . ".ent" )
+    open( $OUTDOC, ">:encoding(UTF-8)", "$name/$lang/$name" . ".ent" )
         || croak( maketext( "Could not open entity file. [_1]", $@ ) );
     print $OUTDOC <<EOL;
 <!ENTITY PRODUCT "$product">
@@ -410,7 +405,7 @@ EOL
 
     close($OUTDOC);
 
-    open( $OUTDOC, ">:utf8", "$name/$lang/images/icon.svg" )
+    open( $OUTDOC, ">:encoding(UTF-8)", "$name/$lang/images/icon.svg" )
         || croak( maketext( "Could not open icon file. [_1]", $@ ) );
     print( $OUTDOC $icon );
     close($OUTDOC);
@@ -464,7 +459,7 @@ No bugs have been reported.
 
 Please report any bugs or feature requests to
 C<publican-list@redhat.com>, or through the web interface at
-L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Fedora&amp;version=rawhide&amp;component=publican>.
+L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Publican&amp;component=publican>.
 
 
 =head1 AUTHOR
