@@ -190,7 +190,7 @@ sub po2xml {
 
     my $OUTDOC;
 
-    open( $OUTDOC, ">:utf8", "$out_file" )
+    open( $OUTDOC, ">:encoding(UTF-8)", "$out_file" )
         || croak( maketext( "Could not open [_1] for output!", $out_file ) );
     print $OUTDOC Publican::Builder::dtd_string(
         { tag => $type, dtdver => $dtdver } );
@@ -686,7 +686,7 @@ sub print_msgs {
 
     my $fh;
 
-    open( $fh, ">:utf8", $pot_file )
+    open( $fh, ">:encoding(UTF-8)", $pot_file )
         or croak(
         maketext(
             "Failed to open output file [_1]. Error: [_2]",
@@ -1041,7 +1041,7 @@ No bugs have been reported.
 
 Please report any bugs or feature requests to
 C<publican-list@redhat.com>, or through the web interface at
-L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Fedora&amp;version=rawhide&amp;component=publican>.
+L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Publican&amp;component=publican>.
 
 
 =head1 AUTHOR
