@@ -62,7 +62,7 @@ sub print_tree {
     my ( $self, $args ) = @_;
     my $dir;
     my $in_file = ( delete $args->{'in_file'}
-            || ( $self->{publican}->param('docname') ) . '.xml' );
+            || ( $self->{publican}->param('mainfile') ) . '.xml' );
 
     my $indent = ( delete $args->{'indent'} || 1 );
 
@@ -74,7 +74,7 @@ sub print_tree {
         );
     }
 
-    if ( $in_file eq $self->{publican}->param('docname') . '.xml' ) {
+    if ( $in_file eq $self->{publican}->param('mainfile') . '.xml' ) {
         $dir = pushd( $self->{publican}->param('xml_lang') );
         logger("$in_file\n");
     }
@@ -123,7 +123,7 @@ sub print_unused {
     my ( $self, $args ) = @_;
     my $dir;
     my $in_file = ( delete $args->{'in_file'}
-            || ( $self->{publican}->param('docname') ) . '.xml' );
+            || ( $self->{publican}->param('mainfile') ) . '.xml' );
 
     if ( %{$args} ) {
         croak(
@@ -142,7 +142,7 @@ sub print_unused {
 
     my $xml_lang = $self->{publican}->param('xml_lang');
 
-    if ( $in_file eq $self->{publican}->param('docname') . '.xml' ) {
+    if ( $in_file eq $self->{publican}->param('mainfile') . '.xml' ) {
         $dir = pushd($xml_lang);
     }
 
@@ -154,7 +154,9 @@ sub print_unused {
     foreach my $node (@nodes) {
         my $filename = $node->attr('href');
         if ( -f $filename && $filename =~ /\.xml$/ ) {
-            $self->print_unused( { 'in_file' => $filename, } );
+            if ( !$node->attr('parse') || $node->attr('parse') ne 'text' ) {
+                $self->print_unused( { 'in_file' => $filename, } );
+            }
             $self->{used_files}->{qq|'$filename'|} = 1;
         }
     }
@@ -169,7 +171,7 @@ sub print_unused {
             $xml_file =~ s/^$xml_lang\///;
             next
                 if (
-                $xml_file eq $self->{publican}->param('docname') . '.xml' );
+                $xml_file eq $self->{publican}->param('mainfile') . '.xml' );
 
             unless ( defined $self->{used_files}->{qq|'$xml_file'|} ) {
                 if ($first) {
@@ -234,7 +236,7 @@ No bugs have been reported.
 
 Please report any bugs or feature requests to
 C<publican-list@redhat.com>, or through the web interface at
-L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Fedora&amp;version=rawhide&amp;component=publican>.
+L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Publican&amp;component=publican>.
 
 
 =head1 AUTHOR
