@@ -6,7 +6,7 @@ use strict;
 use 5.008;
 
 use Carp qw(cluck croak);
-use Config::Simple;
+use Config::Simple '-strict';
 use DBI;
 use Template;
 use Template::Constants;
@@ -141,7 +141,7 @@ sub new {
 
     my $toc_path = $config->param('toc_path') || croak(
         maketext(
-            "[_1] is a manadory field in a site configuration file",
+            "[_1] is a mandatory field in a site configuration file",
             'toc_path'
         )
     );
@@ -149,7 +149,7 @@ sub new {
     my $def_lang  = $config->param('def_lang')  || $DEFAULT_LANG;
     my $db_file   = $config->param('db_file')   || croak(
         maketext(
-            "[_1] is a manadory field in a site configuration file. Check [_2] for validity.",
+            "[_1] is a mandatory field in a site configuration file. Check [_2] for validity.",
             'db_file',
             $site_config
         )
@@ -160,6 +160,7 @@ sub new {
     my $dump      = $config->param('dump')      || undef;
     my $dump_file = $config->param('dump_file') || $DEFAULT_DUMP_FILE;
     my $zip_dump  = $config->param('zip_dump')  || undef;
+    my $manual_toc_update  = $config->param('manual_toc_update')  || 0;
 
     my $self = bless { db_file => $db_file }, $class;
 
@@ -177,6 +178,7 @@ sub new {
     $self->{dump}      = $dump;
     $self->{dump_file} = $dump_file;
     $self->{zip_dump}  = $zip_dump;
+    $self->{manual_toc_update}  = $manual_toc_update;
 
     my $conf = { INCLUDE_PATH => $tmpl_path, };
 
@@ -264,7 +266,10 @@ sub update_or_add_entry {
 
     my $language = delete $arg->{language} || croak "language required";
     my $product  = delete $arg->{product}  || croak "product required";
-    my $version  = delete $arg->{version}  || croak "version required";
+    my $version
+        = defined $arg->{version}
+        ? delete $arg->{version}
+        : croak "update_or_add_entry: version required";
     my $name     = delete $arg->{name}     || croak "name required";
     my $format   = delete $arg->{format}   || croak "format required";
     my $product_label = delete $arg->{product_label};
@@ -328,7 +333,10 @@ sub add_entry {
 
     my $language = delete $arg->{language} || croak "language required";
     my $product  = delete $arg->{product}  || croak "product required";
-    my $version  = delete $arg->{version}  || croak "version required";
+    my $version
+        = defined $arg->{version}
+        ? delete $arg->{version}
+        : croak "add_entry: version required";
     my $name     = delete $arg->{name}     || croak "name required";
     my $format   = delete $arg->{format}   || croak "format required";
     my $product_label = delete $arg->{product_label};
@@ -366,7 +374,10 @@ sub update_entry {
     my $ID       = delete $arg->{ID}       || croak "ID required";
     my $language = delete $arg->{language} || croak "language required";
     my $product  = delete $arg->{product}  || croak "product required";
-    my $version  = delete $arg->{version}  || croak "version required";
+    my $version
+        = defined $arg->{version}
+        ? delete $arg->{version}
+        : croak "update_entry: version required";
     my $name     = delete $arg->{name}     || croak "name required";
     my $format   = delete $arg->{format}   || croak "format required";
     my $product_label = delete $arg->{product_label};
@@ -403,7 +414,10 @@ sub del_entry {
 
     my $language = delete $arg->{language} || croak "language required";
     my $product  = delete $arg->{product}  || croak "product required";
-    my $version  = delete $arg->{version}  || croak "version required";
+    my $version
+        = defined $arg->{version}
+        ? delete $arg->{version}
+        : croak "del_entry: version required";
     my $name     = delete $arg->{name}     || croak "name required";
     my $format   = delete $arg->{format}   || croak "format required";
 
@@ -431,7 +445,10 @@ sub get_entry_id {
 
     my $language = delete $arg->{language} || croak "language required";
     my $product  = delete $arg->{product}  || croak "product required";
-    my $version  = delete $arg->{version}  || croak "version required";
+    my $version
+        = defined $arg->{version}
+        ? delete $arg->{version}
+        : croak "get_entry_id version required";
     my $name     = delete $arg->{name}     || croak "name required";
     my $format   = delete $arg->{format}   || croak "format required";
 
@@ -557,10 +574,14 @@ sub regen_all_toc {
     my ( $self, $arg ) = @_;
     my $OUT;
 
+    my $force = delete $arg->{force};
+
     if ( $arg && %{$arg} ) {
         croak "unknown args: " . join( ", ", keys %{$arg} );
     }
 
+    return if($self->{manual_toc_update} && !$force);
+
     my $langs = $self->get_lang_list();
 
     my @fulltoc        = ();
@@ -636,7 +657,7 @@ sub regen_all_toc {
     $self->{Template}->process(
         'static_toc.tmpl', $vars,
         $self->{toc_path} . "/toc.html",
-        binmode => ':utf8'
+        binmode => ':encoding(UTF-8)'
     ) or croak( $self->{Template}->error() );
 
     $self->stats();
@@ -646,7 +667,7 @@ sub regen_all_toc {
     $self->{Template}->process(
         'Sitemap.tmpl', $vars,
         $self->{toc_path} . "/Sitemap",
-        binmode => ':utf8'
+        binmode => ':encoding(UTF-8)'
     ) or croak( $self->{Template}->error() );
 
     # regenerate main index.html
@@ -662,7 +683,7 @@ sub regen_all_toc {
     $self->{Template}->process(
         'index.tmpl', $vars,
         $self->{toc_path} . "/index.html",
-        binmode => ':utf8'
+        binmode => ':encoding(UTF-8)'
     ) or croak( $self->{Template}->error() );
 
     # This file contains all the langauges.
@@ -677,7 +698,7 @@ sub regen_all_toc {
     $self->{Template}->process(
         'opds-langs.tmpl', $opds_vars,
         $self->{toc_path} . "/opds.xml",
-        binmode => ':utf8'
+        binmode => ':encoding(UTF-8)'
     ) or croak( $self->{Template}->error() );
 
     $self->xml_dump() if ( $self->{dump} );
@@ -1031,7 +1052,7 @@ SEARCH
         $self->{Template}->process(
             'opds.tmpl', $opds_vars,
             $self->{toc_path} . "/$language/opds-$product.xml",
-            binmode => ':utf8'
+            binmode => ':encoding(UTF-8)'
         ) or croak( $self->{Template}->error() );
 
         my %opds_p_url = (
@@ -1054,7 +1075,7 @@ SEARCH
     $self->{Template}->process(
         'toc.tmpl', $vars,
         $self->{toc_path} . "/$language/toc.html",
-        binmode => ':utf8'
+        binmode => ':encoding(UTF-8)'
     ) or croak( $self->{Template}->error() );
 
     # This file contains all products for this langauge.
@@ -1069,7 +1090,7 @@ SEARCH
     $self->{Template}->process(
         'opds-prods.tmpl', $opds_vars,
         $self->{toc_path} . "/$language/opds.xml",
-        binmode => ':utf8'
+        binmode => ':encoding(UTF-8)'
     ) or croak( $self->{Template}->error() );
 
     return \@products;
@@ -1169,7 +1190,7 @@ GET_COUNTS
         $self->{Template}->process(
             'stats.tmpl', $vars,
             $self->{toc_path} . "/$lang/Site_Statistics.html",
-            binmode => ':utf8'
+            binmode => ':encoding(UTF-8)'
         ) or croak( $self->{Template}->error() );
     }
 
