@@ -5,7 +5,7 @@ use warnings;
 use 5.008;
 use Carp;
 use XML::TreeBuilder;
-use Config::Simple;
+use Config::Simple '-strict';
 use Publican;
 use File::Path;
 use Image::Magick;
@@ -62,7 +62,7 @@ my %MAP_OUT = (
     'biblioentry'   => { 'block'         => 1 },
     'othercredit'   => { 'block'         => 1 },
     'legalnotice'   => { 'block'         => 1 },
-    'address'       => { 'block'         => 1 },
+    'address'       => { 'block'         => 1, 'verbatim' => 1 },
     'book'          => { 'block'         => 1 },
     'article'       => { 'block'         => 1 },
     'part'          => { 'block'         => 1 },
@@ -92,13 +92,13 @@ my %MAP_OUT = (
     'refname'       => { 'newline_after' => 1 },
     'refnamediv'    => { 'block'         => 1, 'id_node' => 'refname' },
     'manvolnum'     => { 'newline_after' => 1 },
-    'street'        => { 'newline_after' => 1 },
+    'street'        => {},
     'city'          => {},
     'state'         => {},
     'postcode'      => {},
     'coutry'        => {},
-    'phone'    => { 'newline_after' => 1 },
-    'fax'      => { 'newline_after' => 1 },
+    'phone'         => {},
+    'fax'           => {},
     'pob'      => {},
     'subtitle' => { 'newline_after' => 1 },
     'screen'           => { 'block'       => 1, 'verbatim'      => 1 },
@@ -167,7 +167,7 @@ my %MAP_OUT = (
     'issuenum'          => { 'newline_after' => 1 },
     'edition'           => { 'newline_after' => 1 },
     'pubdate'           => { 'newline_after' => 1 },
-    'productname'       => { 'newline_after' => 1 },
+    'productname'       => { 'newline_after' => 1, mixed_mode    => 1 },
     'productnumber'     => { 'newline_after' => 1 },
     'pubsnumber'        => { 'newline_after' => 1 },
     'contrib'           => { 'newline_after' => 1 },
@@ -176,7 +176,7 @@ my %MAP_OUT = (
     'orgname'           => { 'newline_after' => 1 },
     'orgdiv'            => { 'newline_after' => 1 },
     'citetitle'      => {},
-    'country'        => { 'newline_after' => 1 },
+    'country'        => {},
     'trademark'      => {},
     'ulink'          => {},
     'firstterm'      => {},
@@ -232,7 +232,7 @@ my %MAP_OUT = (
     'property'      => {},
     'see'              => { 'newline_after' => 1, },
     'seealso'          => { 'newline_after' => 1, },
-    'step'             => { 'block'         => 1 },
+    'step'             => { 'block'         => 1, 'keep_id' => 1 },
     'substeps'         => { 'block'         => 1 },
     'stepalternatives' => { 'block'         => 1 },
     'systemitem'       => {},
@@ -609,6 +609,7 @@ sub print_xml {
     my $dtdver  = $self->{publican}->param('dtdver');
     my $docname = $self->{publican}->param('docname');
     my $lang    = $self->{config}->param('lang');
+    my $main_file = $self->{publican}->param('mainfile');
 
     if ($xml_doc) {
         my $file = $out_file;
@@ -650,7 +651,7 @@ sub print_xml {
         $xml_doc->root()->delete();
 
         my $OUTDOC;
-        open( $OUTDOC, ">:utf8", "$out_file" )
+        open( $OUTDOC, ">:encoding(UTF-8)", "$out_file" )
             || croak(
             maketext( "Could not open [_1] for output!", $out_file ) );
 
@@ -659,8 +660,8 @@ sub print_xml {
         # Will be unset when processing common files outside books
         if ($docname) {
             my $xml_lang = $self->{publican}->param('xml_lang');
-            if ( -e "$xml_lang/$docname" . '.ent' ) {
-                $ent_file = "$path$docname.ent";
+            if ( -e "$xml_lang/$main_file" . '.ent' ) {
+                $ent_file = "$path$main_file.ent";
             }
         }
 
@@ -697,7 +698,7 @@ sub my_as_XML {
     my $empty_element_map = $tree->_empty_element_map;
 
     my $STRICT = 0;    # $self->{publican}->param('strict');
-    my $show_unknown = $self->{config}->param('show_unknown');
+    my $show_unknown = $self->{publican}->param('show_unknown');
     my $clean_id     = $self->{config}->param('clean_id');
     my $lang         = $self->{config}->param('lang');
 
@@ -893,7 +894,13 @@ sub my_as_XML {
                         and !@{ $node->content_array_ref() } )
                     {
                         push( @xml, $node->starttag_XML( undef, 1 ) );
-                        if ( $MAP_OUT{$tag}->{'newline_after'} ) {
+                        if (
+                            $MAP_OUT{$tag}->{newline_after}
+                            && (   ( not defined $MAP_OUT{$tag}->{mixed_mode} )
+                                || ( not $MAP_OUT{$tag}->{mixed_mode} )
+                                || ( not $node->look_up( '_tag', 'para' ) ) )
+                          )
+                        {
                             push( @xml, "\n", $indent x $depth );
                         }
                     }
@@ -955,7 +962,13 @@ sub my_as_XML {
                         push( @xml, $node->endtag_XML() );
                     }    # otherwise it will have been an <... /> tag.
 
-                    if ( $MAP_OUT{$tag}->{'newline_after'} ) {
+                    if (
+                        $MAP_OUT{$tag}->{newline_after}
+                        && (   ( not defined $MAP_OUT{$tag}->{mixed_mode} )
+                            || ( not $MAP_OUT{$tag}->{mixed_mode} )
+                            || ( not $node->look_up( '_tag', 'para' ) ) )
+                      )
+                    {
                         push( @xml, "\n", $indent x $depth );
                     }
 
@@ -1290,7 +1303,7 @@ No bugs have been reported.
 
 Please report any bugs or feature requests to
 C<publican-list@redhat.com>, or through the web interface at
-L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Fedora&#59amp;version=rawhide&amp;component=publican>.
+L<https://bugzilla.redhat.com/bugzilla/enter_bug.cgi?product=Publican&#59amp;version=rawhide&amp;component=publican>.
 
 =head1 AUTHOR
 
